@@ -1,6 +1,7 @@
 # Built in Modules
 import subprocess
 import time
+
 # Local package imports
 from .script import Script
 
@@ -8,8 +9,9 @@ from .script import Script
 def submit(script: Script,
            tmp_work_script: str = './tmp_workfile.sh',
            tmp_profile_script: str = './tmp_profilefile.sh',
-           bash_options: list = [''],
-           leave_scripts: bool = True,
+           bash_options: list = None,
+           leave_scripts: bool = False,
+           submit: bool = True,
            test: bool = False):
     '''
     Create the temporary profile file and temporary work script in order to submit them to the appropriate queuing
@@ -33,7 +35,9 @@ def submit(script: Script,
         If True, leaves scripts that are created, but does not submit them. Instead, it prints out the command it would
         have used if it had submitted them.
     '''
-    script.create_profilefile(tmp_work_script, tmp_profile_script, bash_options)
+    if bash_options is None:
+        bash_options = ['']
+    script.create_profilefile(bash_options)
     if test:
         print('The following command would be used to submit a job to the queue:')
         print(' '.join([getattr(script, 'submission'), getattr(script, 'tmp_profile_script')]))
@@ -42,8 +46,10 @@ def submit(script: Script,
         time.sleep(1)
 
     if leave_scripts or test:
+        time.sleep(1)
+        subprocess.run(' '.join(["mv", getattr(script, 'tmp_profile_script'), tmp_profile_script]), shell=True)
+        if getattr(script, 'tmp_work_script') is not None:
+            subprocess.run(' '.join(["mv", getattr(script, 'tmp_work_script'), tmp_work_script]), shell=True)
         return
     else:
-        subprocess.run(f'rm {tmp_profile_script}', shell=True)
-        subprocess.run(f'rm {tmp_work_script}', shell=True)
         return
